@@ -1,6 +1,6 @@
 package Ion;
 # ABSTRACT: A clear and concise API for writing TCP servers and clients
-$Ion::VERSION = '0.04';
+$Ion::VERSION = '0.05';
 use common::sense;
 
 use Carp;
@@ -69,7 +69,7 @@ Ion - A clear and concise API for writing TCP servers and clients
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -184,6 +184,66 @@ C<join> with it later.
   my $pending  = async { <$conn> };
   my $response = $pending->join;
 
+=head1 MESSAGE FORMATS
+
+Sending a raw line of text is sometimes desireable, but complex applications
+will want to use an established protocol when transmitting complex data. Rather
+than fill request handling logic with the details of encoding and decoding data
+for transmission, the routines used for translating structured data into line
+data and vice versa may be specified using the >> and << operators,
+respectively.
+
+The syntax is identical for both servers and client connections. When applied
+to a server instance, client connections accepted on the server side inherit
+the server's configuration (note: the connecting client code will need to be
+similarly configured).
+
+Multiple routines may be chained together as a single expression or multiple
+statements with the assignment version of each operator (>>= and <<=). When
+more than one routine is specified, they will each be called in turn on the
+result of the previous routine, with the first routine receiving the raw line
+data.
+
+=head2 EXAMPLE: JSON
+
+  use Ion;
+  use JSON::XS;
+
+  my $server = Listen;
+  $server << sub{ decode_json(shift) };
+  $server >> sub{ encode_json(shift) };
+
+  while (my $conn = <$server>) {
+    while (my $data = <$conn>) {              # $data is perl data
+      $conn->({foo => 'bar', baz => 'bat'});  # $conn is sent json: "{'foo': 'bar', 'baz': 'bat'}"
+    }
+  }
+
+=head2 EXAMPLE: CHAINING
+
+  use Ion;
+  use Data::Dumper;
+  use MIME::Base64 qw(encode_base64 decode_base64);
+
+  my $client = Connect somehost => 4242;
+
+  # Compound expression
+  $client << sub{ decode_base64(shift) }                # decode line format
+    << sub{ my $msg = eval shift; $@ && die $@; $msg }; # eval perl string
+
+  # Individual statements
+  $client >>= sub{ Dumper(shift) };                     # serialize with Dumper
+  $client >>= sub{ encode_base64(shift, '') };          # single line of base64
+
+=head1 ENDLINES
+
+As one would expect using the <> operator, the value of C<$/> controls the character
+or string used to match the end of a line of input from the socket. It is also appended
+to all output.
+
+  local $/ = "\n\n";
+  my $http_request = <$conn>;
+
 =head1 AUTHOR
 
 Jeff Ober <sysread@fastmail.fm>
